************
Getting Help
************

If you find a bug, or need help getting :rst:dir:`autoclasstoc` to work, please 
open a new issue_ on Github.  `Pull requests`_ are also welcome!

.. _issue: https://github.com/kalekundert/autoclasstoc/issues
.. _pull requests: https://github.com/kalekundert/autoclasstoc/pulls 
